package org.ajc.core;

import org.aspectj.tools.ant.taskdefs.AjcTask;

import protoj.core.ArgRunnable;
import protoj.core.CompileFeature;
import protoj.lang.StandardProject;

// ajc shell script compiles and invokes this main class.
public final class AjcCore {
	public static void main(String[] args) {
		AjcCore core = new AjcCore(args);

		// process the commands captured from the command line
		core.dispatchCommands();
	}

	private StandardProject project;

	public AjcCore(String[] args) {
		project = new StandardProject(args, "ajc Version 1.0");

		// load time weaving is enabled for this project
		project.getDispatchFeature().initLoadTimeWeaving(null);

		// the ajc compiler is used to compile the entire project
		project.getCompileFeature().initConfig(true,
				new ArgRunnable<CompileFeature>() {
					public void run(CompileFeature feature) {
						AjcTask compileTask = feature.getAjcCompileTask()
								.getCompileTask();
						compileTask.setMaxmem("16m");
						compileTask.setSource("1.5");
					}
				});

		// a new vm is used to run all commands with the specified main class
		project.getDispatchFeature().initBootstrap("org.ajc.system.AjcProject",
				"16m");
	}

	public StandardProject getProject() {
		return project;
	}

	public void dispatchCommands() {
		getProject().getDispatchFeature().dispatchCommands();
	}

}
